/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */

// Wait for the deviceready event before using any of Cordova's device APIs.
// See https://cordova.apache.org/docs/en/latest/cordova/events/events.html#deviceready

/*
* cordova 原生代码，启动APP
* by zxl 20210425
* */
document.addEventListener('deviceready', onDeviceReady, false);

var myDb = null;//数据库sqllite

function onDeviceReady() {
    window.open = cordova.InAppBrowser.open;
    document.addEventListener("jpush.receiveRegistrationId", function (event) {
        //alert("receiveRegistrationId" + JSON.stringify(event.data));
    }, false);
    initiateUI();

    myDb = window.sqlitePlugin.openDatabase({
        name: 'hryy.db',
        location: 'default',
        //location: cordova.file.externalRootDirectory + "hryy/data/",
        androidDatabaseImplementation: 2
    },
    function callBack(db) {
        db.transaction(function (tx) {
            //alert("创建数据库成功")
            db.transaction(function (tx) {
                tx.executeSql('CREATE TABLE IF NOT EXISTS cache_data (url char(32) NOT NULL PRIMARY KEY,local_path,create_time,visit_time)');
            }, function (error) {
                //alert("创建表cache_data失败")
                //console.log('transaction error: ' + error.message);
            }, function () {
                //alert("创建表cache_data成功")
                //console.log('transaction ok');
                db.transaction(function (tx) {//保证缓存最多寸500条数据
                    tx.executeSql('CREATE INDEX IF NOT EXISTS url_index ON cache_data(url)');
                }, function (error) {
                    //alert("创建索引失败")
                    //console.log('transaction error: ' + error.message);
                }, function () {
                    //alert("创建索引成功")
                    //console.log('transaction ok');
                });
            });
        }, function (err) {
            //console.log('Open database ERROR: ' + JSON.stringify(err));
        });
    });

    writeDirectory();
    //通知验证引导开启
    window.HrhnUtilPlugin.checkNotificationPermission(null, null, null);
}

function  writeDirectory(){
    //文件夹创建失败回调
    function onErrorGetDir(error){
        //alert("文件夹创建失败！")
    }
    function errorCallback(e) {
        //console.log(e.toString());
        //alert(e.toString());
    }
    //var dirUri = cordova.file.externalApplicationStorageDirectory;
    var dirUri = cordova.file.externalCacheDirectory;
    //alert(dirUri);
    window.resolveLocalFileSystemURI(dirUri,function (entry) {
        entry.getDirectory("cache_data", {
            create: true,
        },function (dirEntry) {
            dirEntry.getDirectory('template', { create: true }, function (subDirEntry) {}, onErrorGetDir);
            dirEntry.getDirectory('file', { create: true }, function (subDirEntry) {}, onErrorGetDir);
            dirEntry.getDirectory('photos', { create: true }, function (subDirEntry) {}, onErrorGetDir);
        },onErrorGetDir)
    },errorCallback)
}

// 获得id
var getRegistrationID = function() {
    window.JPush.getRegistrationID(onGetRegistrationID);
};
var onGetRegistrationID = function(data) {
    try {
        console.log("JPushPlugin:registrationID is " + data);
        if (data.length == 0) {
            var t1 = window.setTimeout(getRegistrationID, 1000);
        }
    } catch (exception) {
        console.log(exception);
    }
};

var onTagsWithAlias = function(event) {
    try {
        console.log("onTagsWithAlias");
        var result = "result code:" + event.resultCode + " ";
        result += "tags:" + event.tags + " ";
        result += "alias:" + event.alias + " ";
        // $("#tagAliasResult").html(result);
    } catch (exception) {
        console.log(exception)
    }
};

var badgeNumb = 0;
var onOpenNotificationM = function(event) {
    try {
        var alertContent;
        if (device.platform == "Android") {
            alertContent = event.alert;
        } else {
            alertContent = event.aps.alert;
        }

        badgeNumb = badgeNumb - 1;
        badgeNumb = badgeNumb<=0 ? 0 : badgeNumb;
        window.JPush.setBadgeNumber(badgeNumb);
        alert("请及时查看：" + alertContent);
    } catch (exception) {
        // alert("JPushPlugin:onOpenNotificationM" + exception);
    }
};

var onReceiveNotificationX = function(event) {
    try {
        var alertContent;
        if (device.platform == "Android") {
            alertContent = event.alert;
        } else {
            alertContent = event.aps.alert;
        }
        // $("#notificationResult").html(alertContent);

        badgeNumb = badgeNumb + 1;
        window.JPush.setBadgeNumber(badgeNumb);
    } catch (exception) {
        console.log(exception)
    }
};

var onReceiveMessageZ = function(event) {
  try {
    var message;
    if (device.platform == "Android") {
      message = event.message;
    } else {
      message = event.content;
    }
    badgeNumb = badgeNumb + 1;
    window.JPush.setBadgeNumber(badgeNumb);
  } catch (exception) {
    console.log("JPushPlugin:onReceiveMessageZ-->" + exception);
  }
};

var onResumeS = function(event){
  try {
        badgeNumb = 0
        window.JPush.setBadgeNumber(0);
    } catch (exception) {
        console.log("onResumeS-->" + exception);
    }
}
// 初始化
var initiateUI = function() {
  try {
    // window.JPush.init();
    // window.JPush.setDebugMode(false);
    // window.setTimeout(getRegistrationID, 1000);

    /*
    window.setTimeout(function(){
      // 标签的
      setTags()
      getAllTags()
      // cleanTags()
      // 别名的
      setAlias()
      getAlias()
      // deleteAlias()
    }, 5000);
    */

    // if (device.platform != "Android") {
    //   window.JPush.setApplicationIconBadgeNumber(0);
    // }
  } catch (exception) {
    // console.log(exception);
    // alert(exception);
  }
};

// 设置tage
var setTags = function () {
  // alert("设置tage")
  try {
    //你可以设置多个tag
    var tag1 = "1"
    var tag2 = "2"
    var tag3 = "3"
    var tags = []
    if (tag1) {
      tags.push(tag1)
    }
    if (tag2) {
      tags.push(tag2)
    }
    if (tag3) {
      tags.push(tag3)
    }

    window.JPush.setTags({ sequence: 1, tags: tags },
      function (result) {
        // 设置成功时
        // JSON.stringify(result.tags)
        // alert(JSON.stringify(result.tags))
        //  清除
        // _t.cleanTags()
      }, function (error) {
        // alert(error.code)
      })
  } catch (exception) {
    console.log(exception)
  }
}

// 获取tage
var getAllTags = function () {
  // alert("获取tage")
  window.JPush.getAllTags({ sequence: 2 },
    function (result) {
      // 获取标签成功
      // alert(JSON.stringify(result.tags))
      //  清除
      // _t.deleteAlias()
    }, function (error) {
      // alert(error.code)
    })
}
// 清空tage
var cleanTags = function () {
  // alert("清空tage")
    window.JPush.cleanTags({ sequence: 2 },
      function (result) {
        // alert(result.sequence)
      }, function (error) {
        // alert(error.code)
      }
    )
}
// 设置设备别名
var setAlias = function () {
  // alert("设置别名")
    var alias = "122223"
    window.JPush.setAlias({ sequence: 1, alias: alias },
    function (result) {
      // 成功后返回别名
      // result.alias
      // alert(result.alias)
    }, function (error){
      // alert(error.code)
    })
}
// 获取设备别名
var getAlias = function () {
  // alert("获取设备别名")
  window.JPush.getAlias({ sequence: 2 },
    function (result) {
      // 获取成功
      // alert(JSON.stringify(result));
    }, function (error) {
      // alert(error.code)
    }
  )
}
// 删除设备别名
var deleteAlias = function () {
    window.JPush.deleteAlias({ sequence: 3 },
      function (result) {
        // 删除成功
        // alert(JSON.stringify(result));
      }, function (error) {
        // alert(error.code)
      }
    )
}

/*
// 设备加载成功的时候
//document.addEventListener("deviceready", onDeviceReadyS, false);
// 获取点击状态栏中的通知内容时
document.addEventListener("jpush.openNotification", onOpenNotificationM, false);
// 收到消息
document.addEventListener("jpush.receiveNotification", onReceiveNotificationX, false);
// 获取自定义消息
document.addEventListener("jpush.receiveMessage", onReceiveMessageZ, false);
// 处理恢复事件
document.addEventListener("resume", onResumeS, false);
*/

var MD5_CACHE = function (string) {

  function RotateLeft(lValue, iShiftBits) {
      return (lValue << iShiftBits) | (lValue >>> (32 - iShiftBits));
  }

  function AddUnsigned(lX, lY) {
      var lX4, lY4, lX8, lY8, lResult;
      lX8 = (lX & 0x80000000);
      lY8 = (lY & 0x80000000);
      lX4 = (lX & 0x40000000);
      lY4 = (lY & 0x40000000);
      lResult = (lX & 0x3FFFFFFF) + (lY & 0x3FFFFFFF);
      if (lX4 & lY4) {
          return (lResult ^ 0x80000000 ^ lX8 ^ lY8);
      }
      if (lX4 | lY4) {
          if (lResult & 0x40000000) {
              return (lResult ^ 0xC0000000 ^ lX8 ^ lY8);
          } else {
              return (lResult ^ 0x40000000 ^ lX8 ^ lY8);
          }
      } else {
          return (lResult ^ lX8 ^ lY8);
      }
  }

  function F(x, y, z) { return (x & y) | ((~x) & z); }
  function G(x, y, z) { return (x & z) | (y & (~z)); }
  function H(x, y, z) { return (x ^ y ^ z); }
  function I(x, y, z) { return (y ^ (x | (~z))); }

  function FF(a, b, c, d, x, s, ac) {
      a = AddUnsigned(a, AddUnsigned(AddUnsigned(F(b, c, d), x), ac));
      return AddUnsigned(RotateLeft(a, s), b);
  };

  function GG(a, b, c, d, x, s, ac) {
      a = AddUnsigned(a, AddUnsigned(AddUnsigned(G(b, c, d), x), ac));
      return AddUnsigned(RotateLeft(a, s), b);
  };

  function HH(a, b, c, d, x, s, ac) {
      a = AddUnsigned(a, AddUnsigned(AddUnsigned(H(b, c, d), x), ac));
      return AddUnsigned(RotateLeft(a, s), b);
  };

  function II(a, b, c, d, x, s, ac) {
      a = AddUnsigned(a, AddUnsigned(AddUnsigned(I(b, c, d), x), ac));
      return AddUnsigned(RotateLeft(a, s), b);
  };

  function ConvertToWordArray(string) {
      var lWordCount;
      var lMessageLength = string.length;
      var lNumberOfWords_temp1 = lMessageLength + 8;
      var lNumberOfWords_temp2 = (lNumberOfWords_temp1 - (lNumberOfWords_temp1 % 64)) / 64;
      var lNumberOfWords = (lNumberOfWords_temp2 + 1) * 16;
      var lWordArray = Array(lNumberOfWords - 1);
      var lBytePosition = 0;
      var lByteCount = 0;
      while (lByteCount < lMessageLength) {
          lWordCount = (lByteCount - (lByteCount % 4)) / 4;
          lBytePosition = (lByteCount % 4) * 8;
          lWordArray[lWordCount] = (lWordArray[lWordCount] | (string.charCodeAt(lByteCount) << lBytePosition));
          lByteCount++;
      }
      lWordCount = (lByteCount - (lByteCount % 4)) / 4;
      lBytePosition = (lByteCount % 4) * 8;
      lWordArray[lWordCount] = lWordArray[lWordCount] | (0x80 << lBytePosition);
      lWordArray[lNumberOfWords - 2] = lMessageLength << 3;
      lWordArray[lNumberOfWords - 1] = lMessageLength >>> 29;
      return lWordArray;
  };

  function WordToHex(lValue) {
      var WordToHexValue = "", WordToHexValue_temp = "", lByte, lCount;
      for (lCount = 0; lCount <= 3; lCount++) {
          lByte = (lValue >>> (lCount * 8)) & 255;
          WordToHexValue_temp = "0" + lByte.toString(16);
          WordToHexValue = WordToHexValue + WordToHexValue_temp.substr(WordToHexValue_temp.length - 2, 2);
      }
      return WordToHexValue;
  };

  function Utf8Encode(string) {
      string = string.replace(/\r\n/g, "\n");
      var utftext = "";

      for (var n = 0; n < string.length; n++) {

          var c = string.charCodeAt(n);

          if (c < 128) {
              utftext += String.fromCharCode(c);
          }
          else if ((c > 127) && (c < 2048)) {
              utftext += String.fromCharCode((c >> 6) | 192);
              utftext += String.fromCharCode((c & 63) | 128);
          }
          else {
              utftext += String.fromCharCode((c >> 12) | 224);
              utftext += String.fromCharCode(((c >> 6) & 63) | 128);
              utftext += String.fromCharCode((c & 63) | 128);
          }

      }

      return utftext;
  };

  var x = Array();
  var k, AA, BB, CC, DD, a, b, c, d;
  var S11 = 7, S12 = 12, S13 = 17, S14 = 22;
  var S21 = 5, S22 = 9, S23 = 14, S24 = 20;
  var S31 = 4, S32 = 11, S33 = 16, S34 = 23;
  var S41 = 6, S42 = 10, S43 = 15, S44 = 21;

  string = Utf8Encode(string);

  x = ConvertToWordArray(string);

  a = 0x67452301; b = 0xEFCDAB89; c = 0x98BADCFE; d = 0x10325476;

  for (k = 0; k < x.length; k += 16) {
      AA = a; BB = b; CC = c; DD = d;
      a = FF(a, b, c, d, x[k + 0], S11, 0xD76AA478);
      d = FF(d, a, b, c, x[k + 1], S12, 0xE8C7B756);
      c = FF(c, d, a, b, x[k + 2], S13, 0x242070DB);
      b = FF(b, c, d, a, x[k + 3], S14, 0xC1BDCEEE);
      a = FF(a, b, c, d, x[k + 4], S11, 0xF57C0FAF);
      d = FF(d, a, b, c, x[k + 5], S12, 0x4787C62A);
      c = FF(c, d, a, b, x[k + 6], S13, 0xA8304613);
      b = FF(b, c, d, a, x[k + 7], S14, 0xFD469501);
      a = FF(a, b, c, d, x[k + 8], S11, 0x698098D8);
      d = FF(d, a, b, c, x[k + 9], S12, 0x8B44F7AF);
      c = FF(c, d, a, b, x[k + 10], S13, 0xFFFF5BB1);
      b = FF(b, c, d, a, x[k + 11], S14, 0x895CD7BE);
      a = FF(a, b, c, d, x[k + 12], S11, 0x6B901122);
      d = FF(d, a, b, c, x[k + 13], S12, 0xFD987193);
      c = FF(c, d, a, b, x[k + 14], S13, 0xA679438E);
      b = FF(b, c, d, a, x[k + 15], S14, 0x49B40821);
      a = GG(a, b, c, d, x[k + 1], S21, 0xF61E2562);
      d = GG(d, a, b, c, x[k + 6], S22, 0xC040B340);
      c = GG(c, d, a, b, x[k + 11], S23, 0x265E5A51);
      b = GG(b, c, d, a, x[k + 0], S24, 0xE9B6C7AA);
      a = GG(a, b, c, d, x[k + 5], S21, 0xD62F105D);
      d = GG(d, a, b, c, x[k + 10], S22, 0x2441453);
      c = GG(c, d, a, b, x[k + 15], S23, 0xD8A1E681);
      b = GG(b, c, d, a, x[k + 4], S24, 0xE7D3FBC8);
      a = GG(a, b, c, d, x[k + 9], S21, 0x21E1CDE6);
      d = GG(d, a, b, c, x[k + 14], S22, 0xC33707D6);
      c = GG(c, d, a, b, x[k + 3], S23, 0xF4D50D87);
      b = GG(b, c, d, a, x[k + 8], S24, 0x455A14ED);
      a = GG(a, b, c, d, x[k + 13], S21, 0xA9E3E905);
      d = GG(d, a, b, c, x[k + 2], S22, 0xFCEFA3F8);
      c = GG(c, d, a, b, x[k + 7], S23, 0x676F02D9);
      b = GG(b, c, d, a, x[k + 12], S24, 0x8D2A4C8A);
      a = HH(a, b, c, d, x[k + 5], S31, 0xFFFA3942);
      d = HH(d, a, b, c, x[k + 8], S32, 0x8771F681);
      c = HH(c, d, a, b, x[k + 11], S33, 0x6D9D6122);
      b = HH(b, c, d, a, x[k + 14], S34, 0xFDE5380C);
      a = HH(a, b, c, d, x[k + 1], S31, 0xA4BEEA44);
      d = HH(d, a, b, c, x[k + 4], S32, 0x4BDECFA9);
      c = HH(c, d, a, b, x[k + 7], S33, 0xF6BB4B60);
      b = HH(b, c, d, a, x[k + 10], S34, 0xBEBFBC70);
      a = HH(a, b, c, d, x[k + 13], S31, 0x289B7EC6);
      d = HH(d, a, b, c, x[k + 0], S32, 0xEAA127FA);
      c = HH(c, d, a, b, x[k + 3], S33, 0xD4EF3085);
      b = HH(b, c, d, a, x[k + 6], S34, 0x4881D05);
      a = HH(a, b, c, d, x[k + 9], S31, 0xD9D4D039);
      d = HH(d, a, b, c, x[k + 12], S32, 0xE6DB99E5);
      c = HH(c, d, a, b, x[k + 15], S33, 0x1FA27CF8);
      b = HH(b, c, d, a, x[k + 2], S34, 0xC4AC5665);
      a = II(a, b, c, d, x[k + 0], S41, 0xF4292244);
      d = II(d, a, b, c, x[k + 7], S42, 0x432AFF97);
      c = II(c, d, a, b, x[k + 14], S43, 0xAB9423A7);
      b = II(b, c, d, a, x[k + 5], S44, 0xFC93A039);
      a = II(a, b, c, d, x[k + 12], S41, 0x655B59C3);
      d = II(d, a, b, c, x[k + 3], S42, 0x8F0CCC92);
      c = II(c, d, a, b, x[k + 10], S43, 0xFFEFF47D);
      b = II(b, c, d, a, x[k + 1], S44, 0x85845DD1);
      a = II(a, b, c, d, x[k + 8], S41, 0x6FA87E4F);
      d = II(d, a, b, c, x[k + 15], S42, 0xFE2CE6E0);
      c = II(c, d, a, b, x[k + 6], S43, 0xA3014314);
      b = II(b, c, d, a, x[k + 13], S44, 0x4E0811A1);
      a = II(a, b, c, d, x[k + 4], S41, 0xF7537E82);
      d = II(d, a, b, c, x[k + 11], S42, 0xBD3AF235);
      c = II(c, d, a, b, x[k + 2], S43, 0x2AD7D2BB);
      b = II(b, c, d, a, x[k + 9], S44, 0xEB86D391);
      a = AddUnsigned(a, AA);
      b = AddUnsigned(b, BB);
      c = AddUnsigned(c, CC);
      d = AddUnsigned(d, DD);
  }

  var temp = WordToHex(a) + WordToHex(b) + WordToHex(c) + WordToHex(d);

  return temp.toLowerCase();
}
